// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
/*****************************************************************************
 *
 *  AngleFormatter.h                            XMM Science Analysis Subsystem
 *
 *  Angle with methods for parsing and formatting
 *
 *  (c) 1999  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: AngleFormatter.h,v 1.5 2002/12/17 17:53:47 jbakker Exp $
 *
 *****************************************************************************/

#ifndef ANGLEFORMATTER_H
#define ANGLEFORMATTER_H

#include <string>              // C++ headers
#include <sstream>


//================================================================
//  Class AngleFormatter
//
//  AngleFormatter handles parsing and printing of angles in a
//  variety of formats. e.g:
//
//      12h34m56.789s    (HMS)
//      12H34M56.789S
//      12d34m56.789s    (DMS)
//     -12d34m56.789s
//      123.456          (Degrees)
//     -1.23456e2
//      12:34:56.789     (Colon separated DMS or HMS)
//
//================================================================

class AngleFormatter
{
public:
    enum AngleMode { Degrees, DMS, HMS };

    // Constructors
    AngleFormatter();
    AngleFormatter(AngleMode mode);

    // Format the angle as a string
    std::string asString(double value, char separator='\0') const;

    // Parse the string, return the value and set the mode
    bool parse(const std::string& str, double& value, char separator='\0');

    void setMode(AngleMode mode=Degrees);
    AngleMode mode() { return _mode; }

private:

    // Parsing 
    static bool parseFields(const std::string& text, char delim1, char delim2,
			    char delim3, double& result, AngleMode mode);

    static bool parseFields(const std::string& text, char separator,
			    double& result, AngleMode mode);

    static bool convertFields(int hrsDeg, int mins, double secs,
			      bool hoursMode, double& result);

    // Member data
    AngleMode  _mode;
};

#endif
