// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
/*****************************************************************************
 *
 *  AngleListParameter.cc                       XMM Science Analysis Subsystem
 *
 *  Angle-std::list task parameter
 *
 *  (c) 1999  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: AngleListParameter.cc,v 1.6 2002/12/17 17:53:48 jbakker Exp $
 *
 *****************************************************************************/

#include "AngleListParameter.h"
#include "Xmm.h"
#include "QuotedString.h" // utils

#include <iostream>


//================================================================
//  Class AngleListParameter
//================================================================

/*** Constructor ***/

AngleListParameter::AngleListParameter()
{
    _mode = AngleFormatter::Degrees;
}


/*** Set the format mode ***/

void AngleListParameter::setMode(AngleFormatter::AngleMode mode)
{
    if (_mode == mode) return;
    _mode = mode;
    notifyView();
}


/*** Format a single element as a std::string ***/

std::string AngleListParameter::doubleAsString(double value) const
{
    AngleFormatter t(_mode);

    return QuotedString(t.asString(value));
}


/*** Parse a single std::list element ***/

bool AngleListParameter::parseDouble(const std::string& s, double& result, bool first)
{
    AngleFormatter t;
    bool ok = t.parse(s, result);

    if(ok && first)                // Base mode on first element
        _mode = t.mode();

    return ok;
}
