// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
/*****************************************************************************
 *
 *  AngleParameter.cc                           XMM Science Analysis Subsystem
 *
 *  Angle task parameter
 *
 *  (c) 1999  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: AngleParameter.cc,v 1.8 2002/12/17 17:53:48 jbakker Exp $
 *
 *****************************************************************************/

#include "AngleParameter.h"
#include "StringToken.h"
#include <errstr.h>

#include <iostream>


//================================================================
//  Class AngleParameter
//================================================================

/*** Constructor ***/

AngleParameter::AngleParameter()
{
    _mode = AngleFormatter::Degrees;
}


/*** Set the format mode ***/

void AngleParameter::setMode(AngleFormatter::AngleMode mode)
{
    if (_mode == mode) return;
    _mode = mode;
    notifyView();
}


/*** Format the parameter value as a std::string ***/

std::string AngleParameter::asString() const
{
    AngleFormatter t(_mode);

    return t.asString(_value);
}


/*** Format the default value as a std::string ***/

std::string AngleParameter::defaultAsString() const
{
    AngleFormatter t(_mode);

    return t.asString(_default);
}


/***  Parse std::string representation and assign to 'value' if it is valid ***/

bool AngleParameter::parse(const std::string& str, double& value)
{
    StringToken token(str);
    AngleFormatter t;
    bool ok = t.parse(token.asUnquotedString(), value);

    if(ok) {
        _mode = t.mode();
    } else {
      errstr << "Parameter '" << _name << "'" << Sas::error("ParamWrongType");
    }

    return ok;
}

