// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
// -*-C++-*-
//
// File:      ChoiceChildParameters.cc
// Author:    Jorgo Bakker (jbakker@astro.estec.esa.nl)
// Generated: Tue May 21 15:36:25 MEST 2002

#include "ChoiceChildParameters.h"
#include "Parameter.h"         // Application headers

// BEGIN private classes
class ParentParameter : public ParameterView
{
public:
  ParentParameter(Parameter* parent, const std::string& imply)
    : _parent(parent), _implicit(imply)
    {
    }
  ~ParentParameter(){}
  bool isSticky() {return true;}
  void updateView() {
    /*
      Only a child can set a parent implicitly, but avoid updating the value,
      if the value was set explicitly on the commandline
    */
    if (!_parent->isSet()) _parent->setNewValue( _implicit);
  }
  
private:
  Parameter* _parent;
  std::string  _implicit;
};
// END private classes


ChoiceChildParameters::ChoiceChildParameters(Parameter* parent)
  : _parent(parent)
{
}

ChoiceChildParameters::~ChoiceChildParameters()
{
}

void ChoiceChildParameters::add(const std::string& choice,Parameter* child)
{
  if (child) {
    (*this)[choice].push_back(child);
    
    // add a notifier to the child
    child->addView(new ParentParameter(_parent,choice));
  }
  else (*this)[choice];
}

std::list<std::string >  ChoiceChildParameters::choices()
{
  std::list<std::string > c;
  if ( empty() ) return c;
  
  // extract all choices from the map...
  for (const_iterator it=begin();it!=end();it++) c.push_back( (*it).first );
  return c;
}
