// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
/*****************************************************************************
 *
 *  RealListParameter.h                         XMM Science Analysis Subsystem
 *
 *  Real std::list task parameter
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: RealListParameter.h,v 1.13 2002/12/17 17:53:49 jbakker Exp $
 *
 *****************************************************************************/

#ifndef REALLISTPARAMETER_H
#define REALLISTPARAMETER_H

#include "Parameter.h"

#include <string>                // C++ headers
#include <vector>


//================================================================
//  Class RealListParameter
//================================================================

class RealListParameter : public Parameter
{
public:
    // Construction
    RealListParameter* clone() { return new RealListParameter(*this); }

    // Value
    std::vector<double>     realListValue() const {return _value;}
    bool               setNewValue(const std::string& value);
    bool               setValue(const std::vector<double>& value);
    int                size() const;
    ParamType          getType() const {return Parameter::RealList;}
    const char*        getTypeName() const { return "real"; }

    // Default
    std::vector<double>     defaultValue() const {return _default;}
    bool               setNewDefault(const std::string& value);
    bool               setDefault(const std::vector<double>& value);
    void               revertToDefault();


    // Fomatting
    std::string             asString() const;
    std::string             defaultAsString() const;

    // Parsing
    virtual bool       parse(const std::string& str, std::vector<double>& value);

protected:

    // Parsing
    virtual bool       parseDouble(const std::string& str, double& value, 
				   bool first=false);
    virtual std::string     doubleAsString(double value) const;

private:
    // called by Parameter::setValue(const Parameter&);
    bool assignValueOf(const Parameter& p) {return setValue(p.realListValue());}

    // Validation
    bool isValid(const std::vector<double>& n) const;
    void reportRangeError(const std::string& valueString);

    // Member data
    std::vector<double>   _value;
    std::vector<double>   _default;
};

#endif
