// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
/*****************************************************************************
 *
 *  RealParameter.h                             XMM Science Analysis Subsystem
 *
 *  Real task parameter
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: RealParameter.h,v 1.14 2002/12/17 17:53:50 jbakker Exp $
 *
 *****************************************************************************/

#ifndef REALPARAMETER_H
#define REALPARAMETER_H

#include <iostream>             // C++ headers
#include "Parameter.h"


//================================================================
//  Class RealParameter
//================================================================

class RealParameter : public Parameter
{
public:
    // Construction
    RealParameter() : _value(0),_default(0) {}
    RealParameter* clone() { return new RealParameter(*this); }

    // Value
    double      realValue() const { return _value; }
    bool        setNewValue(const std::string& value);
    bool        setValue(double value);
    ParamType   getType() const {return Parameter::Real;}
    const char* getTypeName() const { return "real"; }

    // Default
    double     defaultValue() const {return _default;}
    bool       setNewDefault(const std::string& value);
    bool       setDefault(double value);
    void       revertToDefault();

    // Formatting
    std::string      asString() const;
    std::string     defaultAsString() const;

protected:
    // Parsing
    virtual bool parse(const std::string& str, double& value);

    // Member data
    double _value;
    double _default; 

private:
    // called by Parameter::setValue(const Parameter&);
    bool assignValueOf(const Parameter& p) {return setValue(p.realValue());}

    // Validation
    virtual bool isValid(double value) const;
    void reportRangeError(const std::string& valueString);
};

#endif
