// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
/*****************************************************************************
 *
 *  SpecialStringListParameters.h               XMM Science Analysis Subsystem
 *
 *  Subclasses of StringListParameter
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: SpecialStringListParameters.h,v 1.3 2002/04/18 15:44:52 jbakker Exp $
 *
 *****************************************************************************/

#ifndef SPECIALSTRINGLISTPARAMETERS_H
#define SPECIALSTRINGLISTPARAMETERS_H

#include "StringListParameter.h"

#include <string>
#include <vector>


//================================================================
//  Class FileNameListParameter
//================================================================

class FileNameListParameter : public StringListParameter
{
public:

    FileNameListParameter* clone() { return new FileNameListParameter(*this); }
    ParamType getType() const {return Parameter::FileNameList;}
    const char* getTypeName() const { return "file"; }
};


//================================================================
//  Class DirectoryListParameter
//================================================================

class DirectoryListParameter : public StringListParameter
{
public:

    ParamType getType() const {return Parameter::DirectoryList;}
    const char* getTypeName() const { return "directory"; }
    DirectoryListParameter* clone() { return new DirectoryListParameter(*this); }
};


//================================================================
//  Class DataSetListParameter
//================================================================

class DataSetListParameter : public StringListParameter
{
public:

    ParamType getType() const {return Parameter::DataSetList;}
    const char* getTypeName() const { return "dataset"; }
    DataSetListParameter* clone() { return new DataSetListParameter(*this); }
};


//================================================================
//  Class BlockListParameter
//================================================================

class BlockListParameter : public StringListParameter
{
public:

    ParamType getType() const {return Parameter::BlockList;}
    const char* getTypeName() const { return "block"; }
    BlockListParameter* clone() { return new BlockListParameter(*this); }
};


//================================================================
//  Class TableListParameter
//================================================================

class TableListParameter : public StringListParameter
{
public:

    ParamType getType() const {return Parameter::TableList;}
    const char* getTypeName() const { return "table"; }
    TableListParameter* clone() { return new TableListParameter(*this); }
};


//================================================================
//  Class ArrayListParameter
//================================================================

class ArrayListParameter : public StringListParameter
{
public:

    ParamType getType() const {return Parameter::ArrayList;}
    const char* getTypeName() const { return "array"; }
    ArrayListParameter* clone() { return new ArrayListParameter(*this); }
};


//================================================================
//  Class ColumnListParameter
//================================================================

class ColumnListParameter : public StringListParameter
{
public:

    ParamType getType() const {return Parameter::ColumnList;}
    const char* getTypeName() const { return "column"; }
    ColumnListParameter* clone() { return new ColumnListParameter(*this); }
};


//================================================================
//  Class PlaneListParameter
//================================================================

class PlaneListParameter : public StringListParameter
{
public:

    ParamType getType() const {return Parameter::PlaneList;}
    const char* getTypeName() const { return "plane"; }
    PlaneListParameter* clone() { return new PlaneListParameter(*this); }
};


#endif
