// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
/*****************************************************************************
 *
 *  SpecialStringParameters.h                   XMM Science Analysis Subsystem
 *
 *  Subclasses of StringParameter
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: SpecialStringParameters.h,v 1.4 2002/04/18 15:44:52 jbakker Exp $
 *
 *****************************************************************************/

#ifndef SPECIALSTRINGPARAMETERS_H
#define SPECIALSTRINGPARAMETERS_H

#include "StringParameter.h"

#include <string>


//================================================================
//  Class FileNameParameter
//================================================================

class FileNameParameter : public StringParameter
{
public:

    ParamType getType() const {return Parameter::FileName;}
    const char* getTypeName() const { return "file"; }
    FileNameParameter* clone() { return new FileNameParameter(*this); }

private:
};

//================================================================
//  Class DirectoryParameter
//================================================================

class DirectoryParameter : public StringParameter
{
public:

    ParamType getType() const {return Parameter::Directory;}
    const char* getTypeName() const { return "directory"; }
    DirectoryParameter* clone() { return new DirectoryParameter(*this); }
};


//================================================================
//  Class DataSetParameter
//================================================================

class DataSetParameter : public StringParameter
{
public:

    ParamType getType() const {return Parameter::DataSet;}
    const char* getTypeName() const { return "dataset"; }
    DataSetParameter* clone() { return new DataSetParameter(*this); }
};


//================================================================
//  Class BlockParameter
//================================================================

class BlockParameter : public StringParameter
{
public:

    ParamType getType() const {return Parameter::Block;}
    const char* getTypeName() const { return "block"; }
    BlockParameter* clone() { return new BlockParameter(*this); }
};


//================================================================
//  Class TableParameter
//================================================================

class TableParameter : public StringParameter
{
public:

    ParamType getType() const {return Parameter::Table;}
    const char* getTypeName() const { return "table"; }
    TableParameter* clone() { return new TableParameter(*this); }
};


//================================================================
//  Class ArrayParameter
//================================================================

class ArrayParameter : public StringParameter
{
public:

    ParamType getType() const {return Parameter::Array;}
    const char* getTypeName() const { return "array"; }
    ArrayParameter* clone() { return new ArrayParameter(*this); }
};


//================================================================
//  Class ColumnParameter
//================================================================

class ColumnParameter : public StringParameter
{
public:

    ParamType getType() const {return Parameter::Column;}
    const char* getTypeName() const { return "column"; }
    ColumnParameter* clone() { return new ColumnParameter(*this); }
};


//================================================================
//  Class PlaneParameter
//================================================================

class PlaneParameter : public StringParameter
{
public:

    ParamType getType() const {return Parameter::Plane;}
    const char* getTypeName() const { return "plane"; }
    PlaneParameter* clone() { return new PlaneParameter(*this); }
};


//================================================================
//  Class DirOrDataSetParameter
//================================================================

class DirOrDataSetParameter : public StringParameter
{
public:

    ParamType getType() const {return Parameter::DirOrDataSet;}
    const char* getTypeName() const { return "directory|dataset"; }
    DirOrDataSetParameter* clone() { return new DirOrDataSetParameter(*this); }
};

//================================================================
//  Class DirOrFileSetParameter
//================================================================

class DirOrFileParameter : public StringParameter
{
public:

    ParamType getType() const {return Parameter::DirOrFile;}
    const char* getTypeName() const { return "directory|file"; }
    DirOrFileParameter * clone() { return new DirOrFileParameter(*this); }
};
#endif
