// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
/*****************************************************************************
 *
 *  StringToken.cc                              XMM Science Analysis Subsystem
 *
 *  Token class
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: StringToken.cc,v 1.8 2002/12/17 17:53:50 jbakker Exp $
 *
 *****************************************************************************/

#include <cstdlib>                 // C headers

#include <string>                   // C++ headers

#include "StringToken.h"                  // Application headers
#include <errstr.h>
#include <stringutil.h>
#include "StringFns.h"


//================================================================
//  Class StringToken
//================================================================

int StringToken::asInt()
{
    int value;
    _valid = StringFns::parseInt(_s.c_str(), value);

    if(!_valid)
        errstr << "Integer expected at '" << _s << "'" << std::endl;

    return value;
}    

double StringToken::asDouble()
{
    double value;
    _valid = StringFns::parseDouble(_s.c_str(), value);

    if(!_valid)
        errstr << "Real expected at '" << _s << "'" << std::endl;

    return value;
}

bool StringToken::asBool()
{
    bool b = false;
    std::string lw = lowercase(_s);
    if (lw == "yes" || lw == "y" || lw == "1" || lw == "t" || lw == "true")
        b = true;
    else if (lw == "no" || lw == "n" || lw == "0" || lw == "f" || lw == "false")
        b = false;
    else if (lw == "")
        b = false;          // Default for default value
    else {
      errstr << "Bool expected at '" << _s << "'" << std::endl;
        _valid = false;
    }

    return b;
}

std::string StringToken::asUnquotedString()
{
    int length = _s.size();
    if(length >= 2 && _s[0] == '"')
    {
      if(_s[length-1] == '"')
	 return _s.substr(1,length-2);
    }
    return _s;
}

bool StringToken::isUndef() const
{
    return (_s == "");
}

std::ostream& operator<<(std::ostream& os, const StringToken& t)
{
    return os << t._s;
}
