// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
/*****************************************************************************
 *
 *  StringToken.h                               XMM Science Analysis Subsystem
 *
 *  Token class
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: StringToken.h,v 1.4 2002/12/17 17:53:50 jbakker Exp $
 *
 *****************************************************************************/

#ifndef STRINGTOKEN_H
#define STRINGTOKEN_H

#include <iostream>           // C++ headers
#include <string>


//================================================================
//  Class StringToken
//================================================================

class StringToken
{
public:
    StringToken(const std::string& s) : _s(s), _valid(true) {}

    int           asInt();
    double        asDouble();
    const std::string& asString() { return _s; }
    std::string        asUnquotedString();
    bool          asBool();
    bool          isValid() const { return _valid; }
    bool          isUndef() const;

    friend std::ostream& operator<<(std::ostream& os, const StringToken& t);

private:
    std::string _s;
    bool   _valid;
};

#endif
