// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
/*****************************************************************************
 *
 *  TimeListParameter.cc                        XMM Science Analysis Subsystem
 *
 *  Time-std::list task parameter
 *
 *  (c) 1999  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: TimeListParameter.cc,v 1.5 2002/12/17 17:53:50 jbakker Exp $
 *
 *****************************************************************************/

#include "TimeListParameter.h"
#include "Xmm.h"

#include <iostream>


//================================================================
//  Class TimeListParameter
//================================================================

/*** Constructor ***/

TimeListParameter::TimeListParameter()
{
    _mode = TimeFormatter::MRT;
}


/*** Set the format mode ***/

void TimeListParameter::setMode(TimeFormatter::TimeMode mode)
{
    if (_mode == mode) return;
    _mode = mode;
    notifyView();
}


/*** Format a single element as a std::string ***/

std::string TimeListParameter::doubleAsString(double value) const
{
    TimeFormatter t;
    t.setMode(_mode);

    return t.asString(value);
}


/*** Parse a single std::list element ***/

bool TimeListParameter::parseDouble(const std::string& s, double& result, bool first)
{
    TimeFormatter t;
    bool ok = t.parse(s, result);

    if(ok && first)                // Base mode on first element
        _mode = t.mode();

    return ok;
}
