// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
/*****************************************************************************
 *
 *  TimeParameter.cc                           XMM Science Analysis Subsystem
 *
 *  Time task parameter
 *
 *  (c) 1999  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: TimeParameter.cc,v 1.9 2002/12/17 17:53:51 jbakker Exp $
 *
 *****************************************************************************/

#include "TimeParameter.h"
#include "StringToken.h"
#include "STime.h"
#include "Xmm.h"

#include <iostream>
#include <iomanip>
#include <sstream>
#include <cstdlib>


//================================================================
//  Class TimeParameter
//================================================================

/*** Constructor ***/

TimeParameter::TimeParameter()
{
    _mode = TimeFormatter::MRT;
}


/*** Set the format mode ***/

void TimeParameter::setMode(TimeFormatter::TimeMode mode)
{
    if (_mode == mode) return;
    _mode = mode;
    notifyView();
}


/*** Format the parameter value as a std::string ***/

std::string TimeParameter::asString() const
{
    TimeFormatter t;
    t.setMode(_mode);

    return t.asString(_value);
}


/*** Format the default value as a std::string ***/

std::string TimeParameter::defaultAsString() const
{
    TimeFormatter t;
    t.setMode(_mode);

    return t.asString(_default);
}


/***  Parse std::string representation and assign to 'value' if it is valid ***/

bool TimeParameter::parse(const std::string& str, double& value)
{
    StringToken token(str);
    TimeFormatter t;
    bool ok = t.parse(token.asUnquotedString(), value);

    if(ok) {
        _mode = t.mode();
    } else {
      errstr << "Parameter '" << _name << "'" << Sas::error("ParamWrongType");
    }

    return ok;
}

