// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
// -*-C++-*-
//
// File:      XmlInfoReader.cc
// Author:    Jorgo Bakker (jbakker@astro.estec.esa.nl)
// Generated: Mon Nov 26 15:36:30 MET 2001

#include "XmlInfoReader.h"
#include "XmlParamParser.h"
#include "ParameterInfo.h"
#include <errstr.h>
#include <SasFileLocator.h>

XmlInfoReader::XmlInfoReader(const std::string& name,bool isTaskName)
{
  _info = 0;
  std::string parFile;
  if (isTaskName) {
      std::string parName("config/" + name + ".par");
      SasFileLocator locator("");
      parFile = locator.locate(parName, "", false);

      if (parFile.empty())
	errstr << "Could not find parameter file '"
	       << parName << "' in SAS_PATH or SAS_DIR"
	       << Sas::error("ParamFileOpen");
  }
  else {
    parFile=name;
  }

  // This replaces old code
  XmlParamParser parser;
  _info=parser.load(parFile);

  if (_info) _info->setTaskName(isTaskName?name:parFile);
}

XmlInfoReader::~XmlInfoReader()
{
}

ParameterInfo* XmlInfoReader::getParamInfo()
{
  return _info;   // Null pointer if error
}
