// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
/*****************************************************************************
 *
 *  paramcc.cc                                  XMM Science Analysis Subsystem
 *
 *  C task interface to parameter system
 *
 *  (c) 1999  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: paramcc.cc,v 1.12 2002/12/17 17:53:51 jbakker Exp $
 *
 *****************************************************************************/

#include "param.h"           // Application headers
#include "ParamInfoSet.h"

#include <iostream>        // C++ headers


int parameterCount(const std::string& name)
{
  int n = (*gParameters)[name]->size();
  /*
  if(n < 0)
    errstr << "Parameter '" << name << "' is incorrectly accessed as a std::list"
	   << Sas::error("ParamNotList");
  */
  return n;
}


/*** Return value of boolean parameter "name" ***/

bool booleanParameter(const std::string& name, int pos)
{ 
  bool b = false;
  
  Parameter* p = (*gParameters)[name];
  if(p) {
    if (p->size() < 0 && pos > -1) {
      errstr << "Parameter '"
	     << name << "' is incorrectly accessed as a std::list"
	       << Sas::error("ParamNotList");      
    }
    if(pos < 0)
      b = p->boolValue();
    else if(pos < p->size())
      b = p->boolListValue()[pos];
    else
      errstr << "Index " << pos << " is out of range "
	     << "[" << 0 << ',' << p->size() << ") for std::list parameter '" 
	     << name << "'"
	     << Sas::error("ParamIndexRange");
  }
  return b;
}


std::vector<int> boolListParameter(const std::string& name)
{
  return (*gParameters)[name]->boolListValue();
}


/*** Return value of integer parameter "name" ***/

int intParameter(const std::string& name, int pos)
{
  int n = 0;
  
  Parameter* p = (*gParameters)[name];
  
  if(p) {
    if (p->size() < 0 && pos > -1) {
      errstr << "Parameter '"
	     << name << "' is incorrectly accessed as a std::list"
	     << Sas::error("ParamNotList");      
    }
    
    if(pos < 0)
      n = p->intValue();
    else if(pos < p->size())
      n = p->intListValue()[pos];
    else
      errstr << "Index " << pos << " is out of range "
	     << "[" << 0 << ',' << p->size() << ") for std::list parameter '" 
	     << name << "'"
	     << Sas::error("ParamIndexRange");
  }
  return n;
}

std::vector<int> intListParameter(const std::string& name)
{
    return (*gParameters)[name]->intListValue();
}


/*** Return value of real parameter "name" ***/

double realParameter(const std::string& name, int pos)
{ 
  double n = 0;
  
  Parameter* p = (*gParameters)[name];
  if(p) {
    if (p->size() < 0 && pos > -1) {
      errstr << "Parameter '"
	     << name << "' is incorrectly accessed as a std::list"
	     << Sas::error("ParamNotList");      
    }
    else if(pos < 0)
      n = p->realValue();
    else if(pos < p->size())
      n = p->realListValue()[pos];
    else
      errstr << "Index " << pos << " is out of range "
	     << "[" << 0 << ',' << p->size() << ") for std::list parameter '" 
	     << name << "'"
	     << Sas::error("ParamIndexRange");
  }
  return n;
}

std::vector<double> realListParameter(const std::string& name)
{
    return (*gParameters)[name]->realListValue();
}


/*** Return value of std::string parameter "name" ***/

std::string stringParameter(const std::string& name, int pos)
{ 
  std::string s;
  
  Parameter* p = (*gParameters)[name];
  if(p) {
    if (p->size() < 0 && pos > -1) {
      errstr << "Parameter '"
	     << name << "' is incorrectly accessed as a std::list"
	     << Sas::error("ParamNotList");      
    }
    else if(pos < 0)
      s = p->stringValue();
    else if(pos < p->size())
      s = p->stringListValue()[pos];
    else
      errstr << "Index " << pos << " is out of range "
	     << "[" << 0 << ',' << p->size() << ") for std::list parameter '" 
	     << name << "'"
	     << Sas::error("ParamIndexRange");
  }
  return s;
}

std::vector<std::string> stringListParameter(const std::string& name)
{
  return (*gParameters)[name]->stringListValue();
}


//================================================================
//  Used only by taskmain
//================================================================

/*** Open the parameter set for task "name" ***/

void openParameters(const std::string& name)
{
  gParameters = ParamInfoSet::instance()->getParamInfo(name);

  if(gParameters == 0)
    errstr << "Invalid parameter file" << Sas::error("ParamFileInvalid");
}


/*** Close the parameter set ***/

void closeParameters()
{
  if (! gParameters) {
    errstr << "Unloading of parameters requested, but no parameters loaded"
	   << Sas::message(Msg::Lib, Msg::Noisy);
    return;
  }
  
  ParamInfoSet::instance()->resetParamInfo(gParameters->taskName());
  
  gParameters = 0;
}
