// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
/****************************************************************************
 *
 *  testtimeangle.cc                           XMM Science Analysis Subsystem
 *
 *  Test time and angle parameters
 *
 *  (c) 1999  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: testtimeangle.cc,v 1.6 2003/06/16 08:42:44 gvacanti Exp $
 *
 *****************************************************************************/

#include <Parameter.h>               // Application headers
#include <param.h>
#include<cassert>

#include <cmath>                    // C headers

#include <iostream>                // C++ headers
#include <string>

#include <errstr.h>

int main(int argc, char* argv[])
{
    const double epsilon = 1e-5;

    std::string taskname(argv[0]);
    errHandler.name(taskname);

    openParameters(taskname);
    gParameters->parseCommandLine(argc,argv);

    std::cout << std::endl << "Parameter info:" << std::endl 
	 << *gParameters << std::endl;


    /*** Time parameters ***/

    double time0 = -6901632.0;

    double time1  = realParameter("time1");
    std::cout << "time1   = " << time1 << std::endl;
    assert(fabs(time1 - time0) < fabs(time0) * epsilon);

    double time2  = realParameter("time2");
    std::cout << "time2   = " << time2 << std::endl;
    assert(fabs(time2 - time0) < fabs(time0) * epsilon);

    double time3  = realParameter("time3");
    std::cout << "time3   = " << time3 << std::endl;
    assert(fabs(time3 - time0) < fabs(time0) * epsilon);

    double time4  = realParameter("time4");
    std::cout << "time4   = " << time4 << std::endl;
    assert(fabs(time4 - time0) < fabs(time0) * epsilon);

    double time5  = realParameter("time5");
    std::cout << "time5   = " << time5 << std::endl;
    assert(fabs(time5 - time0) < fabs(time0) * epsilon);

    double time6  = realParameter("time6");
    std::cout << "time6   = " << time6 << std::endl;
    assert(fabs(time6 - time0) < fabs(time0) * epsilon);

    double time7  = realParameter("time7");
    std::cout << "time7   = " << time7 << std::endl;
    assert(fabs(time7 - time0) < fabs(time0) * epsilon);

    /*** Time-std::list parameters ***/

    int ntlist1 = parameterCount("tlist1");
    assert(ntlist1 == 3);
    for(int i=0; i<ntlist1; i++)
        std::cout << "tlist1[" << i << "] = " << realParameter("tlist1",i) << std::endl;
    double tref = -6901632.0;
    assert(fabs(realParameter("tlist1",0) - tref) < fabs(tref) * epsilon);
    assert(fabs(realParameter("tlist1",1) - tref) < fabs(tref) * epsilon);
    assert(fabs(realParameter("tlist1",2) - tref) < fabs(tref) * epsilon);

    int ntlist2 = parameterCount("tlist2");
    assert(ntlist2 == 2);
    for(int i=0; i<ntlist2; i++)
        std::cout << "tlist2[" << i << "] = " << realParameter("tlist2",i) << std::endl;
    //    double tref = -6.912e+06;
    assert(fabs(realParameter("tlist2",0) - tref) < fabs(tref) * epsilon);
    assert(fabs(realParameter("tlist2",1) - tref) < fabs(tref) * epsilon);


    /*** Angle parameters ***/

    double aref = 1.23456789;
    double angle1  = realParameter("angle1");
    std::cout << "angle1   = " << angle1 << std::endl;
    assert(fabs(angle1 - aref) < fabs(aref) * epsilon);

    aref = 188.7365833;
    double angle2  = realParameter("angle2");
    std::cout << "angle2   = " << angle2 << std::endl;
    assert(fabs(angle2 - aref) < fabs(aref) * epsilon);

    aref = -188.7365833;;
    double angle3  = realParameter("angle3");
    std::cout << "angle3   = " << angle3 << std::endl;
    assert(fabs(angle3 - aref) < fabs(aref) * epsilon);

    aref = -1.2345678;
    double angle4  = realParameter("angle4");
    std::cout << "angle4   = " << angle4 << std::endl;
    assert(fabs(angle4 - aref) < fabs(aref) * epsilon);


    /*** Angle-std::list parameters ***/

    int nalist1 = parameterCount("alist1");
    assert(nalist1 == 3);
    for(int i=0; i<nalist1; i++)
        std::cout << "alist1[" << i << "] = " << realParameter("alist1",i) << std::endl;
    double alref0 = 1.23456789;
    assert(fabs(realParameter("alist1",0) - alref0) < fabs(alref0) * epsilon);
    double alref1 = 188.7365833;
    assert(fabs(realParameter("alist1",1) - alref1) < fabs(alref1) * epsilon);
    double alref2 = -188.7365833;
    assert(fabs(realParameter("alist1",2) - alref2) < fabs(alref2) * epsilon);

    int nalist2 = parameterCount("alist2");
    assert(nalist2 == 2);
    for(int i=0; i<nalist2; i++)
        std::cout << "alist2[" << i << "] = " << realParameter("alist2",i) << std::endl;
    double alref3 = -1.23456789;
    assert(fabs(realParameter("alist2",0) - alref3) < fabs(alref3) * epsilon);
    double alref4 = 188.7365833;
    assert(fabs(realParameter("alist2",1) - alref4) < fabs(alref4) * epsilon);

    std::cout << gParameters->asCommandLine() << std::endl;


    closeParameters();

    return 0;
}
